@@ -14,24 +14,39 @@ from czsc.data.ts_cache import *
 os.environ['czsc_verbose'] = '1'
 
 
+def test_ts_cache_ths_daily():
+    dc = TsDataCache(data_path='.', sdt='20200101')
+    df = dc.ths_daily('885573.TI', raw_bar=False)
+    assert df.shape[0] == 565 and df.shape[1] == 34
+    df = dc.ths_daily('885573.TI', end_date="20220420", raw_bar=False)
+    assert df.shape[0] == 556 and df.shape[1] == 34
+
+    # 测试被动刷新数据
+    dc = TsDataCache(data_path='.', sdt='20210101')
+    df = dc.ths_daily('885573.TI', raw_bar=False)
+    assert df.shape[0] == 322 and df.shape[1] == 34
+
+    # 测试主动刷新数据
+    dc = TsDataCache(data_path='.', refresh=True, sdt='20210101')
+    df = dc.ths_daily('885573.TI', raw_bar=False)
+    assert df.shape[0] == 322 and df.shape[1] == 34
+
+    dc.clear()
+
+
 def test_ts_cache_daily_basic_new():
     dc = TsDataCache(data_path='.', sdt='20200101', edt='20211024')
-    cache_path = './TS_CACHE_20200101_20211024'
-    assert os.path.exists(cache_path)
     df = dc.daily_basic_new(trade_date='2018-03-15')
     assert df.shape[0] == 3237 and df.shape[1] == 37
 
     dfb = dc.stocks_daily_basic_new(sdt='20211001', edt='20211020')
-    assert dfb.shape[1] == df.shape[1] and len(dfb) == 40407
+    assert dfb.shape[1] == df.shape[1] + 1 and len(dfb) == 40407
     dc.clear()
 
 
 def test_ts_cache_bars():
     """测试获取K线"""
     dc = TsDataCache(data_path='.', sdt='20200101', edt='20211024')
-    cache_path = './TS_CACHE_20200101_20211024'
-    assert os.path.exists(cache_path)
-
     # 测试日线以上数据获取
     bars = dc.pro_bar(ts_code='000001.SZ', asset='E', freq='D',
                       start_date='20200101', end_date='20211024', raw_bar=True)
@@ -71,9 +86,6 @@ def test_ts_cache_bars():
 
 def test_ts_cache():
     dc = TsDataCache(data_path='.', sdt='20200101', edt='20211024')
-    cache_path = './TS_CACHE_20200101_20211024'
-    assert os.path.exists(cache_path)
-
     assert dc.get_next_trade_dates('2022-03-02', 2, 5) == ['20220304', '20220307', '20220308']
     assert dc.get_next_trade_dates('2022-03-02', -1, -4) == ['20220224', '20220225', '20220228']
     assert dc.get_dates_span('20220224', '20220228') == ['20220224', '20220225', '20220228']
@@ -124,5 +136,4 @@ def test_ts_cache():
     bars = dc.ths_daily(ts_code='885566.TI', start_date='20200101', end_date='20211024', raw_bar=False)
     assert len(bars) == 436
 
-    dc.clear()
-    assert not os.path.exists(cache_path)
+    dc.clear()
\ No newline at end of file
